@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     26/07/2003
-## RCS-ID:      $Id: $
+## RCS-ID:      $Id: GLCanvas.pm,v 1.2 2003/09/12 21:32:43 mbarbon Exp $
 ## Copyright:   (c) 2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -14,10 +14,9 @@ package Wx::GLCanvas;
 
 use strict;
 use Wx;
-use OpenGL ();
 use base 'Wx::ScrolledWindow';
 
-$Wx::GLCanvas::VERSION = '0.01';
+$Wx::GLCanvas::VERSION = '0.02';
 
 Wx::wx_boot( 'Wx::GLCanvas', $Wx::GLCanvas::VERSION );
 
@@ -31,7 +30,7 @@ Wx::GLCanvas - interface to wxWindows' OpenGL canvas
 
 =head1 SYNOPSIS
 
-    use OpenGL;
+    use OpenGL; # or any other module providing OpenGL API
     use Wx::GLCanvas;
 
 =head1 DESCRIPTION
@@ -41,7 +40,7 @@ wxPerl distribution (wxGLCanvas).
 
 =head1 AUTHOR
 
-Mattia Barbon <mbarbon@dsi.unive.it>
+Mattia Barbon <mbarbon@cpan.org>
 
 =cut
 
